/* eslint-disable no-nested-ternary */
import React from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
import gaDataset from '../../utils/gaDataset';
import UserDefaultAvatar from '../../assets/user-avatar.svg';
import styles from './AnueAccount.scss';

const cx = classNames.bind(styles);

const AnueAccount = ({ isLogin, avatarSrc, userName, onLogin, onRegister, onClick, enableStatic, dataPrefix }) => {
  const loginGaEvent = { ...gaDataset({ dataPrefix, category: 'Header', action: 'click', label: 'avatar' }) };
  const registerGaEvent = { ...gaDataset({ dataPrefix, category: 'Header', action: 'click', label: 'signup' }) };

  // 登入前顯示
  const loginOptions = (
    <div>
      <span className={cx('button', 'user-login')} onClick={onLogin && onLogin} {...loginGaEvent}>
        登入
      </span>
      <span className={cx('button', 'user-register')} onClick={onRegister && onRegister} {...registerGaEvent}>
        註冊
      </span>
    </div>
  );

  // 登入前顯示 for Static 頁面用 (.net舊站)
  const loginOptionsWithStatic = (
    <div>
      <a className={cx('button', 'user-login')} href={onLogin && onLogin} rel="noopener noreferrer" {...loginGaEvent}>
        登入
      </a>
      <a
        className={cx('button', 'user-register')}
        href={onRegister && onRegister}
        rel="noopener noreferrer"
        {...registerGaEvent}
      >
        註冊
      </a>
    </div>
  );

  // 登入後顯示
  const loginedInfo = (
    <span className={cx('button', 'user-info')} onClick={onClick} title={userName}>
      {userName}
    </span>
  );

  const avatar = !avatarSrc ? UserDefaultAvatar : avatarSrc;

  return (
    <div className={cx('user-login-wrapper')}>
      <img src={avatar} className={cx('user-avatar')} alt="Avatar" />
      {isLogin ? loginedInfo : enableStatic ? loginOptionsWithStatic : loginOptions}
    </div>
  );
};

AnueAccount.propTypes = {
  isLogin: PropTypes.bool,
  avatarSrc: PropTypes.string,
  userName: PropTypes.string,
  onLogin: PropTypes.func,
  onRegister: PropTypes.func,
  onClick: PropTypes.func,
  enableStatic: PropTypes.bool,
  dataPrefix: PropTypes.arrayOf(PropTypes.string),
};

AnueAccount.defaultProps = {
  isLogin: false,
  avatarSrc: null,
  userName: '',
  onLogin: () => {},
  onRegister: () => {},
  onClick: () => {},
  enableStatic: false,
  dataPrefix: ['data-global-ga'],
};

export default AnueAccount;
