/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';
import Header from '../../Header/Header';
import AnueSearchInput from '../AnueSearchInput';
import { MobileMenu } from '../../MobileHeader';
import AccountMenu from '../../AccountMenu/AccountMenu';
import AccountMenuStyles from '../../AccountMenu/__stories__/Container.scss';
import defaultNotes from './AnueSearchInput.md';

const WRAPPER_STYLES = {
  width: '100vw',
  height: '100vh',
  display: 'flex',
  justifyContent: 'flex-start',
  alignItems: 'center',
  flexDirection: 'column',
};

const MOBILE_WRAPPER_STYLES = {
  ...WRAPPER_STYLES,
  backgroundColor: 'rgba(0, 0, 0, 0.5)',
};

const MOBILE_MENU_SEARCH_ICON_WRAPPER = {
  position: 'absolute',
  right: 0,
  top: 0,
  height: '44px',
  display: 'flex',
  justifyContent: 'center',
  alignItems: 'center',
  zIndex: 5,
};

const stories = storiesOf('AnueSearchInput', module);

stories.addDecorator(knobs.withKnobs);

stories.add(
  'Desktop',
  withState({
    hiddenInput: false,
    isFocus: false,
  })(
    withNotes(defaultNotes)(
      withInfo()(() => {
        knobs.boolean('onFocus', false);
        knobs.text('Input Value', '');

        return (
          <div style={WRAPPER_STYLES}>
            <Header
              channel="全站搜尋Bar"
              displayChannelName
              customMenu={<AccountMenu />}
              searchBar={
                <AnueSearchInput
                  onInputChange={e => {
                    const value = e.target.value;

                    knobs.text('Input Value', value);
                  }}
                  onInputFocus={() => {
                    knobs.boolean('onFocus', true);
                  }}
                  customAttribute={{
                    onBlur: () => {
                      knobs.boolean('onFocus', false);
                    },
                  }}
                />
              }
            />
          </div>
        );
      })
    )
  )
);

stories.add(
  'Mobile',
  withState({
    hiddenInput: true,
    isFocus: false,
  })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        knobs.boolean('onFocus', false);
        knobs.text('Input Value', '');

        return (
          <div style={MOBILE_WRAPPER_STYLES}>
            <div className={AccountMenuStyles.mobileWrapper} style={{ backgroundColor: '#fff', height: '100vh' }}>
              <header className={AccountMenuStyles.mobileHeader} style={{ borderBottom: '1px solid #eee' }}>
                <MobileMenu />
                <nav className={AccountMenuStyles.mobileLinks}>
                  <a>外匯</a>
                  <a>市場</a>
                  <a>虛擬貨幣</a>
                </nav>
                <div className={AccountMenuStyles.accountWrapper}>
                  <AccountMenu highlight isLogin />
                </div>
                <div
                  style={{
                    ...MOBILE_MENU_SEARCH_ICON_WRAPPER,
                    width: '100%',
                  }}
                >
                  <AnueSearchInput
                    theme="mobile"
                    hiddenInput={store.state.hiddenInput}
                    onIconClick={() => {
                      store.set({ hiddenInput: !store.state.hiddenInput });
                    }}
                    onInputChange={value => {
                      knobs.text('Input Value', value);
                    }}
                    onInputFocus={() => {
                      knobs.boolean('onFocus', true);
                    }}
                    customAttribute={{
                      onBlur: () => {
                        knobs.boolean('onFocus', false);
                      },
                    }}
                    customInputStyles={{
                      maxWidth: 'calc(100% - 85px)',
                    }}
                  />
                </div>
              </header>
            </div>
          </div>
        );
      })
    )
  )
);
