/* eslint-disable react/prop-types */
/* eslint-disable import/no-extraneous-dependencies */
import React from 'react';
import { storiesOf } from '@storybook/react';
import { withInfo } from '@storybook/addon-info';
import { withNotes } from '@storybook/addon-notes';
import { withState } from '@dump247/storybook-state';
import * as knobs from '@storybook/addon-knobs/react';
import { DOT_POSITION } from '../../constants';
import defaultNotes from '../../__stories__/Carousel.md';
import styles from '../../__stories__/stories.style.scss';
import Carousel from '../Carousel';

const stories = storiesOf('Carousel/Hook', module);

stories.addDecorator(knobs.withKnobs);

stories.add(
  '自動播放',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <Carousel>
          <div className={styles.slide}>A</div>
          <div className={styles.slide}>B</div>
          <div className={styles.slide}>C</div>
        </Carousel>
      );
    })
  )
);

stories.add(
  '手動播放',
  withState({ isPlay: false })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        return (
          <div>
            <Carousel autoPlay={store.state.isPlay}>
              <div className={styles.slide}>A</div>
              <div className={styles.slide}>B</div>
              <div className={styles.slide}>C</div>
            </Carousel>

            <button
              onClick={() => {
                store.set({ isPlay: true });
              }}
              style={{
                padding: '12px 24px',
                cursor: 'pointer',
                backgroundColor: '#666',
                color: '#fff',
                borderRadius: '5px',
                marginTop: '16px',
              }}
            >
              播放
            </button>
          </div>
        );
      })
    )
  )
);

stories.add(
  '導航列固定在下方',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <Carousel dotPosition={DOT_POSITION.FIXED}>
          <div className={styles.slide}>A</div>
          <div className={styles.slide}>B</div>
          <div className={styles.slide}>C</div>
        </Carousel>
      );
    })
  )
);

stories.add(
  '切換速度為 5 秒',
  withNotes(defaultNotes)(
    withInfo()(() => {
      return (
        <Carousel dotPosition={DOT_POSITION.FIXED} speed={5000}>
          <div className={styles.slide}>A</div>
          <div className={styles.slide}>B</div>
          <div className={styles.slide}>C</div>
        </Carousel>
      );
    })
  )
);

stories.add(
  '完成切換後呼叫外部傳入函式',
  withState({ slide: 1 })(
    withNotes(defaultNotes)(
      withInfo()(({ store }) => {
        const style = {
          marginTop: '60px',
        };

        return (
          <div>
            <Carousel onChange={index => store.set({ slide: index + 1 })}>
              <div className={styles.slide}>A</div>
              <div className={styles.slide}>B</div>
              <div className={styles.slide}>C</div>
            </Carousel>

            <p style={style}>目前投影片位置: {store.state.slide}</p>
          </div>
        );
      })
    )
  )
);
