/* eslint import/no-extraneous-dependencies: ["error", {"peerDependencies": true}] */
import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import classNames from 'classnames/bind';
// import cx from 'classnames';
// import getStyleName from '../../utils/getStyleName';
import styles from './Footer.scss';
import footerLinks from './links';
import { footerNavItem } from '../../utils/propTypes';
import gaDataset from '../../utils/gaDataset';

const cx = classNames.bind(styles);

const ANUE_INDEX = 'https://www.cnyes.com';

class Footer extends PureComponent {
  static propTypes = {
    mobileNavs: PropTypes.arrayOf(footerNavItem),
    desktopNavs: PropTypes.arrayOf(footerNavItem),
    socials: PropTypes.arrayOf(footerNavItem),
    now: PropTypes.number.isRequired,
    Link: PropTypes.func,
    dataPrefix: PropTypes.arrayOf(PropTypes.string),
  };

  static defaultProps = {
    mobileNavs: footerLinks.mobileNavs,
    desktopNavs: footerLinks.desktopNavs,
    socials: footerLinks.socials,
    Link: undefined,
    dataPrefix: ['data-global-ga'],
  };

  static renderNavs(navs, dataPrefix) {
    if (!navs) return null;

    return navs.map(item => {
      const { url, name, title, onClick } = item;

      return (
        <a
          href={url}
          onClick={onClick}
          key={`footer-nav-${name}`}
          target="_blank"
          rel="noopener noreferrer"
          {...gaDataset({ dataPrefix, category: 'Footer', action: 'click', label: title })}
        >
          {title}
        </a>
      );
    });
  }

  static renderSocials(socials, dataPrefix) {
    if (!socials) return null;

    return socials.map(item => (
      <div className={cx('social-item')} key={`footer-socials-${item.name}`}>
        <div className={cx('title')}>{item.title}</div>
        <a
          className={`${cx('social-icon')} ${cx(`cnyes-media-${item.name}`)}`}
          href={item.url}
          rel="noopener noreferrer"
          target="_blank"
          {...gaDataset({ dataPrefix, category: 'Footer', action: 'click', label: item.title })}
        >
          {item.title}
        </a>
      </div>
    ));
  }

  render() {
    const { mobileNavs, desktopNavs, socials, now, Link, dataPrefix } = this.props;
    const thisYear = new Date(now).getFullYear();
    const logoClass = cx('footer-logo', 'hidden-mobile', 'logo');
    const socialsClass = cx('footer-socials', 'hidden-mobile', 'socials');

    /* eslint-disable jsx-a11y/accessible-emoji */
    return (
      <div id={cx('cnyes-footer-wrapper')} className={cx('theme-footer-wrapper')}>
        <footer className={cx('main-footer')}>
          <div className={logoClass}>
            {Link ? (
              <Link to="/" {...gaDataset({ dataPrefix, category: 'Footer', action: 'click', label: 'home' })} />
            ) : (
              <a href={ANUE_INDEX} {...gaDataset({ dataPrefix, category: 'Footer', action: 'click', label: 'home' })} />
            )}
          </div>
          <div className={cx('footer-nav')}>
            <nav className={cx('hidden-desktop', 'mobile-nav')}>
              {this.constructor.renderNavs(mobileNavs, dataPrefix)}
            </nav>
            <nav className={cx('hidden-mobile', 'desktop-nav')}>
              {this.constructor.renderNavs(desktopNavs, dataPrefix)}
            </nav>
            <small className={cx('copyright-anue')}>
              <span>©</span>
              <span className={cx('hidden-mobile')}> Copyright</span>
              <span> 2000-{thisYear} Anue鉅亨網 All rights reserved.</span>
              <span className={cx('hidden-mobile')}> 未經授權 不得轉載</span>
            </small>
          </div>
          <div className={socialsClass}>{this.constructor.renderSocials(socials, dataPrefix)}</div>
        </footer>
      </div>
    );
  }
}

export default Footer;
