import React from 'react';
import cx from 'classnames';
import PropTypes from 'prop-types';
import gaDataset from '../../../utils/gaDataset';
import styles from './NavItem.scss';

function NavItem({ item, navTitle, onClick, dataPrefix }) {
  const linkStyle = cx(styles['nav-board-link'], item.highlight && styles.highlight, item.bold && styles.bold);

  return (
    <a
      key={item.name}
      className={linkStyle}
      href={item.url}
      data-ga-category="側選單"
      data-ga-action={navTitle}
      data-ga-label={item.title}
      {...gaDataset({ dataPrefix, category: 'Drawer', action: 'click', label: `${navTitle}_${item.title}` })}
      onClick={onClick}
    >
      {item.title}
    </a>
  );
}

NavItem.propTypes = {
  item: PropTypes.shape({
    name: PropTypes.string.isRequired,
    title: PropTypes.string.isRequired,
    url: PropTypes.string.isRequired,
  }).isRequired,
  navTitle: PropTypes.string.isRequired,
  onClick: PropTypes.func,
  dataPrefix: PropTypes.arrayOf(PropTypes.string),
};

NavItem.defaultProps = {
  onClick: undefined,
  dataPrefix: ['data-global-ga'],
};

export default NavItem;
