import { getGenerator } from '../SvgChart';

describe('SvgChart generator', () => {
  const defaultPd = 0;
  const defaultMarginTop = 0;
  const defaultW = 80;
  const defaultH = 40;
  const defaultMinX = 1585008000;
  const defaultMaxX = 1585029600;
  const defaultMinY = 17402.93;
  const defaultMaxY = 18092.35;
  const defaultSession = [[1585008000, 1585017000], [1585020600, 1585029600]];

  const generator = ({
    pd = defaultPd,
    w = defaultW,
    h = defaultH,
    minX = defaultMinX,
    maxX = defaultMaxX,
    minY = defaultMinY,
    maxY = defaultMaxY,
    session = defaultSession,
    marginTop = defaultMarginTop,
  } = {}) => getGenerator(pd, w, h, minX, maxX, minY, maxY, session, marginTop);

  it('should calculate x-axis range base on session', () => {
    const { xr } = generator();

    expect(xr).toBe(1585029600 - 1585020600 + 1585017000 - 1585008000);
  });

  it('should calculate y-axis range base on minY and minX', () => {
    const { yr } = generator();

    expect(yr).toBe(defaultMaxY - defaultMinY);
  });

  it('should scale x-axis (timestamp) base on width', () => {
    const { getX } = generator();

    expect(getX(1585008000)).toBe(0);
    expect(getX(1585029600)).toBe(defaultW);
  });

  it('should scale y-axis (value) base on height in reverse order', () => {
    const { getY } = generator();

    expect(getY(17402.93)).toBe(defaultH);
    expect(getY(18092.35)).toBe(0);
  });

  it('should calculate y-axis base on marginTop', () => {
    const marginTop = 10;
    const { getY } = generator({ marginTop });

    expect(getY(17402.93)).toBe(defaultH);
    expect(getY(18092.35)).toBe(0 + marginTop);
  });
});
